Navigation on deletion
----------------------

XXX after_deletion_path, pre_web_edit

Controlling output url
-----------------------

XXX write me

Controling notification references
----------------------------------

XXX write me
